==> node-typescript_3.3.3333.orig.tar.gz: TypeScript-3.3.3333/tests/baselines/reference/requireOfJsonFileTypes.js <==
//// [tests/cases/compiler/requireOfJsonFileTypes.ts] ////

//// [file1.ts]
import b = require('./b.json');
import c = require('./c.json');
import d = require('./d.json');
import e = require('./e.json');
import f = require('./f.json');
import g = require('./g.json');

let booleanLiteral: boolean, nullLiteral: null;
let stringLiteral: string;
let numberLiteral: number;

booleanLiteral = b.a;
stringLiteral = b.b;
nullLiteral = b.c;
booleanLiteral = b.d;
const stringOrNumberOrNull: string | number | null = c[0];
stringLiteral = d;
numberLiteral = e;
numberLiteral = f[0];
booleanLiteral = g[0];

//// [b.json]
{
    "a": true,
    "b": "hello",
    "c": null,
    "d": false
}

//// [c.json]
["a", null, "string"]

//// [d.json]
"dConfig"

//// [e.json]
-10

//// [f.json]
[-10, 30]

//// [g.json]
[true, false]

//// [out/b.json]
{
    "a": true,
    "b": "hello",
    "c": null,
    "d": false
}
//// [out/c.json]
["a", null, "string"]
//// [out/d.json]
"dConfig"
//// [out/e.json]
-10
//// [out/f.json]
[-10, 30]
//// [out/g.json]
[true, false]
//// [out/file1.js]
"use strict";
exports.__esModule = true;
var b = require("./b.json");
var c = require("./c.json");
var d = require("./d.json");
var e = require("./e.json");
var f = require("./f.json");
var g = require("./g.json");
var booleanLiteral, nullLiteral;
var stringLiteral;
var numberLiteral;
booleanLiteral = b.a;
stringLiteral = b.b;
nullLiteral = b.c;
booleanLiteral = b.d;
var stringOrNumberOrNull = c[0];
stringLiteral = d;
numberLiteral = e;
numberLiteral = f[0];
booleanLiteral = g[0];

==> node-typescript_3.7.2.orig.tar.gz: TypeScript-3.7.2/tests/baselines/reference/requireOfJsonFileTypes.js <==
//// [tests/cases/compiler/requireOfJsonFileTypes.ts] ////

//// [file1.ts]
import b = require('./b.json');
import c = require('./c.json');
import d = require('./d.json');
import e = require('./e.json');
import f = require('./f.json');
import g = require('./g.json');

let booleanLiteral: boolean, nullLiteral: null;
let stringLiteral: string;
let numberLiteral: number;

booleanLiteral = b.a;
stringLiteral = b.b;
nullLiteral = b.c;
booleanLiteral = b.d;
const stringOrNumberOrNull: string | number | null = c[0];
stringLiteral = d;
numberLiteral = e;
numberLiteral = f[0];
booleanLiteral = g[0];

//// [b.json]
{
    "a": true,
    "b": "hello",
    "c": null,
    "d": false
}

//// [c.json]
["a", null, "string"]

//// [d.json]
"dConfig"

//// [e.json]
-10

//// [f.json]
[-10, 30]

//// [g.json]
[true, false]

//// [out/b.json]
{
    "a": true,
    "b": "hello",
    "c": null,
    "d": false
}
//// [out/c.json]
["a", null, "string"]
//// [out/d.json]
"dConfig"
//// [out/e.json]
-10
//// [out/f.json]
[-10, 30]
//// [out/g.json]
[true, false]
//// [out/file1.js]
"use strict";
exports.__esModule = true;
var b = require("./b.json");
var c = require("./c.json");
var d = require("./d.json");
var e = require("./e.json");
var f = require("./f.json");
var g = require("./g.json");
var booleanLiteral, nullLiteral;
var stringLiteral;
var numberLiteral;
booleanLiteral = b.a;
stringLiteral = b.b;
nullLiteral = b.c;
booleanLiteral = b.d;
var stringOrNumberOrNull = c[0];
stringLiteral = d;
numberLiteral = e;
numberLiteral = f[0];
booleanLiteral = g[0];


//// [out/b.d.ts]
export declare const a: boolean;
export declare const b: string;
export declare const c: null;
export declare const d: boolean;
//// [out/c.d.ts]
declare const _exports: (string | null)[];
export = _exports;
//// [out/d.d.ts]
declare const _exports: string;
export = _exports;
//// [out/e.d.ts]
declare const _exports: number;
export = _exports;
//// [out/f.d.ts]
declare const _exports: number[];
export = _exports;
//// [out/g.d.ts]
declare const _exports: boolean[];
export = _exports;
//// [out/file1.d.ts]
export {};
